@@ -2,6 +2,7 @@ import json
 import os
 import platform
 import subprocess
+from enum import Enum
 from typing import Callable, Dict, List, Union
 
 import pyautogui
@@ -22,6 +23,11 @@ app = typer.Typer(
 app.add_typer(mic.app, name="mic")
 
 
+class SupportedLanguage(str, Enum):
+    en = "en"
+    zh = "zh"
+
+
 def _version_callback(value: bool) -> None:
     if value:
         typer.echo(f"{__app_name__} {__version__}")
@@ -72,7 +78,7 @@ def start(
         "-s",
         help="Set max record seconds if your custom command is long.",
     ),
-    lang: str = typer.Option(
+    lang: SupportedLanguage = typer.Option(
         "en",
         "--language",
         "-l",
@@ -82,7 +88,7 @@ def start(
     action_matcher = ActionMatcher()
 
     try:
-        with open(os.path.join(os.path.dirname(__file__)) + "/configs/actions.json") as f:
+        with open(os.path.join(os.path.dirname(__file__)) + "/configs/actions.json", encoding="utf-8") as f:
             data = json.load(f)
 
             try:
